.. Layout based on https://github.com/pydanny/cookiecutter-django/blob/master/CONTRIBUTORS.rst

Contributors
============

`Contributors <https://github.com/apriha/lineage/graphs/contributors>`_ to
``lineage`` are listed below.

Core Developers
---------------

=========== ==========
Name        GitHub
=========== ==========
Andrew Riha `@apriha`_
=========== ==========

.. _@apriha: https://github.com/apriha

Other Contributors
------------------

Listed in alphabetical order.

=============== ===============
Name            GitHub
=============== ===============
Anatoli Babenia `@abitrolly`_
Kevin Arvai     `@arvkevi`_
Will Jones      `@willgdjones`_
Yoan Bouzin
=============== ===============

.. _@abitrolly: https://github.com/abitrolly
.. _@arvkevi: https://github.com/arvkevi
.. _@willgdjones: https://github.com/willgdjones
